@@ -1,7 +1,7 @@
 package Bencher::Scenarios::DataSahResolve;
 
-our $DATE = '2017-01-25'; # DATE
-our $VERSION = '0.003'; # VERSION
+our $DATE = '2021-08-01'; # DATE
+our $VERSION = '0.004'; # VERSION
 
 1;
 # ABSTRACT: Benchmark Data::Sah::Resolve
@@ -18,7 +18,7 @@ Bencher::Scenarios::DataSahResolve - Benchmark Data::Sah::Resolve
 
 =head1 VERSION
 
-This document describes version 0.003 of Bencher::Scenarios::DataSahResolve (from Perl distribution Bencher-Scenarios-DataSahResolve), released on 2017-01-25.
+This document describes version 0.004 of Bencher::Scenarios::DataSahResolve (from Perl distribution Bencher-Scenarios-DataSahResolve), released on 2021-08-01.
 
 =head1 DESCRIPTION
 
@@ -28,8 +28,16 @@ This distribution contains the following L<Bencher> scenario modules:
 
 =item * L<Bencher::Scenario::DataSahResolve::Overhead>
 
+=item * L<Bencher::Scenario::DataSahResolve::Resolve>
+
 =back
 
+=head1 CONTRIBUTOR
+
+=for stopwords perlancar (@pc-office)
+
+perlancar (@pc-office) <perlancar@gmail.com>
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Bencher-Scenarios-DataSahResolve>.
@@ -52,7 +60,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017 by perlancar@cpan.org.
+This software is copyright (c) 2021, 2017, 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
